############################################################
#                                                          #
#              Information                                 #
#                                                          #
############################################################

#Dates: 1/01/2021 24h *de moment*   
#Time zone and hour format: Hour of the day is shown in UTC. Value at Hour 1 correspond to the hour starting at 1 and ending at 2. As April falls in summer time (UTC + 2 hours), to convert from local time to UTC we move two hours backwards. So, 7 am local time is 5 am UTC.   
#Pollutant: NO2   
#Catalunya    
#Sites: 72 monitoring stations
#Observations source: 
#Models intercompared:  
#  Raw model from Caliope
#  LOOCV applied to Caliope
#-------------------------------------------------------------------------------
# Measure the time it takes to run the analysis
start_time <- Sys.time()
#Images 1 and 2 are the path where we want to save the graphics obtained in time series and temporal variations
Images1  <- "/esarchive/scratch/mhajji/Meriem/UK_regional/proves_LOOCV/time_series_LOOCV/"
Images2  <- "/esarchive/scratch/mhajji/Meriem/UK_regional/proves_LOOCV/temporal_variation_LOOCV/"
path_repositori <- "/esarchive/scratch/mhajji/codes/geostats/UK_repository/"
#-------------------------------------------------------------------------------
#              LOOCV TO CALIOPE DATA WITH CATALONIA OBSERVATIONS
#-------------------------------------------------------------------------------

############################################################
#                                                          #
#              Set libraries                               #
#                                                          #
############################################################
# ! check the version of the package or R if any library or function does not work correctly

library(urbanR)
library(RNetCDF)
library(sp)
library(sf)
#library(mapview)
library(ncdf4)
library(rgeos) 
library(ggplot2)
library(plyr) #OJO! la llibreria plyr ha de ser cridada abans que dplyr 
library(dplyr)
library(broom)
library(magrittr)
library(ggpubr)
library(raster)
library(rgdal)
#library(tmap)
library(gstat)
library(sp)
library(abind)
library(openair)
#library(Metrics)

#-------------------------------------------------------------------------------

## LOAD config_file

args = commandArgs(TRUE)
if (length(args) > 0) {
  configFile_path <- args[1]
} else {
  cat("\n***WARNING: no ConfigFile was provided. Using default ConfigFile.\n")
}

#config_file it's a file where we change the data, where we want to save the results, etc. so now we extract these data from it:
configFile_path <- "/esarchive/scratch/mhajji/Meriem/RUN_UK_regional/LOOCV/config_file_2.yml"

config          <- yaml::yaml.load_file(configFile_path)
sim_folder_path <- config$sim_folder_path
obs_path        <- config$obs_path
model_path      <- config$model_path
save_result     =  config$save_result
date_time_end   <- config$date_time_end
date_time_begin <- config$date_time_begin
variogram_path  =  config$variogram_path
name            =  config$doc_name

print("Configuration file: done")

# As we had problems with Ordinary and Universal Kriging variograms, we saved one of each to read them in case we have problems with the one executed for a specific date or hour
variogram_ok =paste0(variogram_path, "Variogram_OK.rds")
variogram_uk =paste0(variogram_path, "Variogram_UK.rds")


############################################################
#                                                          #
#              Set temporal context                        #
#                                                          #
############################################################

#date_times et fa un super vector d'una  columna, dia per dia, hora per hora des de l'inici fins a la data final p.ex: 2021-01-01 00:00:00
date_times <- data_frame_dates(date_time_begin = date_time_begin,
                               date_time_end = date_time_end)

#dates: Llista de caracters anymesdia p.ex: 20210101
dates <- unique(paste0(as.character(strftime(date_times[, 1], format="%Y", tz = "UTC")),
                       as.character(strftime(date_times[, 1], format="%m", tz = "UTC")),
                       as.character(strftime(date_times[, 1], format="%d", tz = "UTC"))))
#year_month: igual que date pero anymes p.ex: 202101
year_month <- unique(paste0(as.character(strftime(date_times[, 1], format="%Y", tz = "UTC")),
                            as.character(strftime(date_times[, 1], format="%m", tz = "UTC"))))

############################################################
#                                                          #
#                 Load Observations                        #
#                                                          #
############################################################

source(paste0(path_repositori,"load_obs_cat.R"))
print("Observations load: done")


############################################################
#                                                          #
#                 Load Model                               #
#                                                          #
############################################################

source(paste0(path_repositori,"load_caliope_cat.R")) 
print("Raw model load: done")

############################################################
#                                                          #
#                 Loop Universal Kriging                   #
#                                                          #
############################################################

source(paste0(path_repositori,"loop_uk_cat.R")) 
print("LOOCV applied to Caliope: done")

############################################################
#                                                          #
#              evaluation statistics                       #
#                                                          #
############################################################

source(paste0(path_repositori,"stadistics_uk_cat.R")) 
print("Evaluation statistics LOOCV vs raw model: done")


############################################################
#                                                          #
#                   Time series                            #
#                                                          #
############################################################

source(paste0(path_repositori,"time_series_uk_cat.R")) 
print("Time Series avaluation: done")


############################################################
#                                                          #
#              Temporal variations                         #
#                                                          #
############################################################

source(paste0(path_repositori,"temporal_variation_uk_cat.R")) 
print("Temporal variation: done")

#-------------------------------------------------------------------------------
#Temps que triga en executar-se el fitxer

end_time <- Sys.time()
temps_total <- end_time-start_time
print(temps_total)
